@@ -33,5 +33,8 @@ exports.main = function() {
                 .replace(/<host>/g, document.location.host),
             ["error"]);
     };
+
+    // Initialise the bottom tool bar
+    toolbar.bottom.initialize(document.getElementById("toolbar-bottom"));
 };
 
